Package: MethPed
Type: Package
Version: 1.40.0
Date: 2016-01-01
Title: A DNA methylation classifier tool for the identification of
        pediatric brain tumor subtypes
Authors@R: c( person(given = "Mohammad Tanvir", family = "Ahamed", role
        = c("aut","trl")), person(given = "Anna", family =
        "Danielsson", role = "aut"), person(given = "Szilárd", family =
        "Nemes", role = c("aut","trl")), person(given = "Helena",
        family = "Carén", role = c("aut","cre","cph"),email =
        "helenacarenlab@gmail.com"))
Depends: R (>= 3.0.0), Biobase
Suggests: BiocStyle, knitr, markdown, impute
Imports: randomForest, grDevices, graphics, stats
VignetteBuilder: knitr
biocViews: ImmunoOncology, DNAMethylation, Classification, Epigenetics
Encoding: UTF-8
Description: Classification of pediatric tumors into biologically
        defined subtypes is challenging and multifaceted approaches are
        needed. For this aim, we developed a diagnostic classifier
        based on DNA methylation profiles. We offer MethPed as an
        easy-to-use toolbox that allows researchers and clinical
        diagnosticians to test single samples as well as large cohorts
        for subclass prediction of pediatric brain tumors.  The current
        version of MethPed can classify the following tumor
        diagnoses/subgroups: Diffuse Intrinsic Pontine Glioma (DIPG),
        Ependymoma, Embryonal tumors with multilayered rosettes (ETMR),
        Glioblastoma (GBM), Medulloblastoma (MB) - Group 3 (MB_Gr3),
        Group 4 (MB_Gr3), Group WNT (MB_WNT), Group SHH (MB_SHH) and
        Pilocytic Astrocytoma (PiloAstro).
License: GPL-2
RoxygenNote: 5.0.1
NeedsCompilation: no
Author: Mohammad Tanvir Ahamed [aut, trl], Anna Danielsson [aut],
        Szilárd Nemes [aut, trl], Helena Carén [aut, cre, cph]
Maintainer: Helena Carén <helenacarenlab@gmail.com>
Repository: https://bioc-release.r-universe.dev
Date/Publication: 2026-04-28 12:42:50 UTC
RemoteUrl: https://github.com/bioc/MethPed
RemoteRef: RELEASE_3_23
RemoteSha: 0d2a1cad7587ce67b3f968c2eadd74043bd21f39
Packaged: 2026-04-29 23:17:22 UTC; root
Built: R 4.6.0; ; 2026-04-30 00:34:10 UTC; unix
