# Generated by roxygen2: do not edit by hand

S3method(MethPed,ExpressionSet)
S3method(MethPed,data.frame)
S3method(MethPed,default)
S3method(MethPed,matrix)
S3method(checkNA,ExpressionSet)
S3method(checkNA,data.frame)
S3method(checkNA,default)
S3method(checkNA,matrix)
S3method(plot,methped)
S3method(summary,methped)
export(MethPed)
export(checkNA)
export(probeMis)
import(Biobase)
importFrom(grDevices,dev.new)
importFrom(grDevices,dev.off)
importFrom(grDevices,rainbow)
importFrom(graphics,barplot)
importFrom(graphics,legend)
importFrom(graphics,par)
importFrom(randomForest,randomForest)
importFrom(stats,predict)
